@@ -129,7 +129,7 @@ def finetune(data, training_config):
             env_model.compile(optimizer=optimizer, loss=env_model.compute_loss,  
                               metrics=['accuracy'])
             
-            env_model.fit(train_dataset.shuffle(1000).batch(batch_size), epochs=epoch_count, batch_size=16,
+            env_model.fit(train_dataset.shuffle(1000).batch(batch_size), epochs=epoch_count, batch_size=batch_size,
                           validation_data=train_dataset.shuffle(1000).batch(batch_size))
             print("Model trained successfully!!!")
             
